.. tomotok documentation master file, created by
   sphinx-quickstart on Tue Jun  9 10:48:03 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. title:: Home

Tomotok's documentation
=======================

Welcome to the Tomotok project for tomography of tokamak plasma.

.. toctree::
   :maxdepth: 2
   :numbered:
   :caption: Table of Contents

   welcome
   licence
   install
   inversions/inversions
   auxilia/auxilia
   gui/gui
   glossary

.. toctree::
   :caption: Api Doc

   api/tomotok.core
   api/tomotok.gui

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
